==> haskell-doctest-0.22.3-26.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest
version:              0.22.3
visibility:           public
id:                   doctest-0.22.3-5uqJFh0bqoK9mgzuxOY3MM
key:                  doctest-0.22.3-5uqJFh0bqoK9mgzuxOY3MM
license:              MIT
copyright:            (c) 2009-2024 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    `doctest` is a tool that checks [examples](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810775744)
    and [properties](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810771856)
    in Haddock comments.
    It is similar in spirit to the [popular Python module with the same name](https://docs.python.org/3/library/doctest.html).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  475c367b21bc76317a214c8aba37b701
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Internal.Extract
    Test.DocTest.Internal.Location Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Run

hidden-modules:
    Extract GhcUtil Imports Info Interpreter
    Language.Haskell.GhciWrapper Location Options PackageDBs Parse
    Property Run Runner Runner.Example Util Paths_doctest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctest-0.22.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctest-0.22.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctest-0.22.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest
hs-libraries:         HSdoctest-0.22.3-5uqJFh0bqoK9mgzuxOY3MM
depends:
    base-4.18.2.1 code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ process-1.6.19.0
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.22.3-28-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest
version:              0.22.3
visibility:           public
id:                   doctest-0.22.3-Bm8zSZ15XlFJMCSCRMMhm5
key:                  doctest-0.22.3-Bm8zSZ15XlFJMCSCRMMhm5
license:              MIT
copyright:            (c) 2009-2024 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    `doctest` is a tool that checks [examples](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810775744)
    and [properties](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810771856)
    in Haddock comments.
    It is similar in spirit to the [popular Python module with the same name](https://docs.python.org/3/library/doctest.html).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  abc039ec4208074bef42ea14af286fc2
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Internal.Extract
    Test.DocTest.Internal.Location Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Run

hidden-modules:
    Extract GhcUtil Imports Info Interpreter
    Language.Haskell.GhciWrapper Location Options PackageDBs Parse
    Property Run Runner Runner.Example Util Paths_doctest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctest-0.22.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctest-0.22.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctest-0.22.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest
hs-libraries:         HSdoctest-0.22.3-Bm8zSZ15XlFJMCSCRMMhm5
depends:
    base-4.18.2.1 code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ process-1.6.19.0
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
